@@ -113,25 +113,14 @@ static const char AA_PROFILE_BASE[] =
 "  deny /sys/kernel/debug/{,**} rwklx,\n"
 "\n"
 "  # allow paths to be made dependent, shared, private or unbindable\n"
-"  # TODO: This currently doesn't work due to the apparmor parser treating those as allowing all mounts.\n"
-"#  mount options=(rw,make-slave) -> **,\n"
-"#  mount options=(rw,make-rslave) -> **,\n"
-"#  mount options=(rw,make-shared) -> **,\n"
-"#  mount options=(rw,make-rshared) -> **,\n"
-"#  mount options=(rw,make-private) -> **,\n"
-"#  mount options=(rw,make-rprivate) -> **,\n"
-"#  mount options=(rw,make-unbindable) -> **,\n"
-"#  mount options=(rw,make-runbindable) -> **,\n"
-"\n"
-"# Allow limited modification of mount propagation\n"
-"  mount options=(rw,make-slave) -> /,\n"
-"  mount options=(rw,make-rslave) -> /,\n"
-"  mount options=(rw,make-shared) -> /,\n"
-"  mount options=(rw,make-rshared) -> /,\n"
-"  mount options=(rw,make-private) -> /,\n"
-"  mount options=(rw,make-rprivate) -> /,\n"
-"  mount options=(rw,make-unbindable) -> /,\n"
-"  mount options=(rw,make-runbindable) -> /,\n"
+"  mount options=(rw,make-slave) -> **,\n"
+"  mount options=(rw,make-rslave) -> **,\n"
+"  mount options=(rw,make-shared) -> **,\n"
+"  mount options=(rw,make-rshared) -> **,\n"
+"  mount options=(rw,make-private) -> **,\n"
+"  mount options=(rw,make-rprivate) -> **,\n"
+"  mount options=(rw,make-unbindable) -> **,\n"
+"  mount options=(rw,make-runbindable) -> **,\n"
 "\n"
 "  # allow bind-mounts of anything except /proc, /sys and /dev\n"
 "  mount options=(rw,bind) /[^spd]*{,/**},\n"
@@ -329,10 +318,10 @@ static const char AA_PROFILE_NESTING_BASE[] =
 "  mount fstype=proc -> /usr/lib/*/lxc/**,\n"
 "  mount fstype=sysfs -> /usr/lib/*/lxc/**,\n"
 "\n"
-"  # Allow nested LXD\n"
-"  mount none -> /var/lib/lxd/shmounts/,\n"
-"  mount /var/lib/lxd/shmounts/ -> /var/lib/lxd/shmounts/,\n"
-"  mount options=bind /var/lib/lxd/shmounts/** -> /var/lib/lxd/**,\n"
+"  # Allow nested Incus\n"
+"  mount none -> /var/lib/incus/shmounts/,\n"
+"  mount /var/lib/incus/shmounts/ -> /var/lib/incus/shmounts/,\n"
+"  mount options=bind /var/lib/incus/shmounts/** -> /var/lib/incus/**,\n"
 "\n"
 "  # TODO: There doesn't seem to be a way to ask for:\n"
 "  # mount options=(ro,nosuid,nodev,noexec,remount,bind),\n"
